@@ -1,19 +1,9 @@
 package Egg::Model::DBIC::Schema;
 #
-# Copyright (C) 2007 Bee Flag, Corp, All Rights Reserved.
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Schema.pm 49 2007-03-21 02:27:49Z lushe $
+# $Id: Schema.pm 103 2007-05-08 00:20:39Z lushe $
 #
-use strict;
-use warnings;
-use base qw/DBIx::Class::Schema Egg::Base/;
-
-our $VERSION = '0.01';
-
-1;
-
-__END__
 
 =head1 NAME
 
@@ -34,11 +24,19 @@ Egg::Model::DBIC::Schema - Base class for Schema module for Egg.
 
 This module has succeeded to DBIx::Class::Schema and Egg::Base.
 
+=cut
+use strict;
+use warnings;
+use base qw/DBIx::Class::Schema Egg::Base/;
+
+our $VERSION = '2.00';
+
 =head1 SEE ALSO
 
 L<DBIx::Class>,
+L<DBIx::Class::Schema>,
 L<Egg::Model::DBIC>,
-L<Egg::Helper::M::DBIC>,
+L<Egg::Helper::Model::DBIC>,
 L<Egg::Release>,
 
 =head1 AUTHOR
@@ -54,3 +52,5 @@ it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
+1;
